===========
TTUN Client
===========

|Deploy|

.. |Deploy| image:: https://github.com/tomvanderlee/ttun-client/actions/workflows/python-publish.yml/badge.svg
   :target: https://github.com/tomvanderlee/ttun-client/actions/workflows/python-publish.yml

Expose a localport via your selfhosted `TTUN Server <https://github.com/tomvanderlee/ttun-server>`_

Installing
----------

::

    pip install ttun

Developing
----------

1. Create and activate a python 3.10 virtual environment

2. Install requirements::

    pip install -r requirements.txt

3. Run::

    python -m ttun
